@@ -2,7 +2,7 @@
  * License. If a copy of the this license was not distributed with this
  * file, you can obtain one from http://opensource.org/licenses/BSD-2-Clause. */
 
- // Copyright 2014-2016, Drew Schmidt.  All rights reserved.
+ // Copyright 2014-2017 Drew Schmidt.  All rights reserved.
 
 
 #include <RNACI.h>
@@ -29,8 +29,6 @@
 // Constants
 SEXP R_meminfo_retvals(SEXP retval)
 {
-  R_INIT;
-  
   SEXP RET;
   newRvec(RET, 1, "str");
   
@@ -41,7 +39,7 @@ SEXP R_meminfo_retvals(SEXP retval)
   else if (INT(retval) == PLATFORM_ERROR)
     SET_STRING_ELT(RET, 0, mkChar("Your operating system is not supported at this time."));
   
-  R_END;
+  unhideGC();
   return RET;
 }
 
@@ -49,8 +47,6 @@ SEXP R_meminfo_retvals(SEXP retval)
 // Wrappers
 SEXP R_meminfo_raminfo()
 {
-  R_INIT;
-  
   int ret;
   int ct = 0;
   memsize_t tmp;
@@ -63,10 +59,10 @@ SEXP R_meminfo_raminfo()
   TRYFUNC(bufferram);
   TRYFUNC(cachedram);
   
-  R_list_names = make_list_names(ct, "totalram", "freeram", "bufferram", "cachedram");
-  R_list = make_list(R_list_names, ct, totalram, freeram, bufferram, cachedram);
+  make_list_names(R_list_names, ct, "totalram", "freeram", "bufferram", "cachedram");
+  make_list(R_list, R_list_names, ct, totalram, freeram, bufferram, cachedram);
   
-  R_END;
+  unhideGC();
   return R_list;
 }
 
@@ -74,8 +70,6 @@ SEXP R_meminfo_raminfo()
 
 SEXP R_meminfo_swapinfo()
 {
-  R_INIT;
-  
   int ret;
   int ct = 0;
   memsize_t tmp;
@@ -87,11 +81,10 @@ SEXP R_meminfo_swapinfo()
   TRYFUNC(freeswap);
   TRYFUNC(cachedswap);
   
-  R_list_names = make_list_names(ct, "totalswap", "freeswap", "cachedswap");
-  R_list = make_list(R_list_names, ct, totalswap, freeswap, cachedswap);
+  make_list_names(R_list_names, ct, "totalswap", "freeswap", "cachedswap");
+  make_list(R_list, R_list_names, ct, totalswap, freeswap, cachedswap);
   
-  
-  R_END;
+  unhideGC();
   return R_list;
 }
 
@@ -99,7 +92,6 @@ SEXP R_meminfo_swapinfo()
 
 SEXP R_meminfo_procinfo()
 {
-  R_INIT;
   memsize_t tmp;
   int ct = 0;
   int ret;
@@ -109,11 +101,10 @@ SEXP R_meminfo_procinfo()
   TRYFUNC(process_size);
   TRYFUNC(process_peak);
   
-  R_list_names = make_list_names(ct, "size", "peak");
-  R_list = make_list(R_list_names, ct, process_size, process_peak);
+  make_list_names(R_list_names, ct, "size", "peak");
+  make_list(R_list, R_list_names, ct, process_size, process_peak);
   
-  
-  R_END;
+  unhideGC();
   return R_list;
 }
 
@@ -121,8 +112,6 @@ SEXP R_meminfo_procinfo()
 
 SEXP R_meminfo_cacheinfo_size(SEXP level)
 {
-  R_INIT;
-  
   int ret;
   int ct = 0;
   cachesize_t tmp;
@@ -131,7 +120,7 @@ SEXP R_meminfo_cacheinfo_size(SEXP level)
   
   CACHEFUN(cachesize, RET, INT(level));
   
-  R_END;
+  unhideGC();
   return RET;
 }
 
@@ -139,8 +128,6 @@ SEXP R_meminfo_cacheinfo_size(SEXP level)
 
 SEXP R_meminfo_cacheinfo_linesize()
 {
-  R_INIT;
-  
   int ret;
   int ct = 0;
   cachesize_t tmp;
@@ -149,7 +136,7 @@ SEXP R_meminfo_cacheinfo_linesize()
   
   TRYFUNC(cachelinesize);
   
-  R_END;
+  unhideGC();
   return cachelinesize;
 }
 
@@ -157,7 +144,6 @@ SEXP R_meminfo_cacheinfo_linesize()
 
 SEXP R_meminfo_filesize(SEXP filename)
 {
-  R_INIT;
   SEXP filesize;
   newRvec(filesize, 1, "dbl");
   
@@ -166,6 +152,6 @@ SEXP R_meminfo_filesize(SEXP filename)
   
   DBL(filesize) = (double) size;
   
-  R_END;
+  unhideGC();
   return filesize;
 }
